@@ -45,18 +45,15 @@ def runTask(moduleName: str, **parDict: dict[str, Any]):
         module.clean()
 
 
-def _isDev() -> bool:
+def _isDev():
     return sys.executable.endswith("python.exe")
 
 
 def _checkLockFile():
     lockFile = getPath(_workspacePath, "task.lock")
     if os.path.isfile(lockFile):
-        if _isDev():
-            print(f"不支持重复执行 {lockFile}")
-            hold("当前调试模式下，输入unlock可继续", True, "unlock")
-        else:
-            raise Exception(f"不支持重复执行 {lockFile}")
+        print(f"不支持重复执行 {lockFile}")
+        hold("如果确认上次执行是意外退出，输入unlock可继续", True, "unlock")
     writeFile(lockFile, time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()))
     return lockFile
 
